# Wavin Sentio
> API Wrapper for Wavin Sentio underfloor heating system.

Enables you to query status of thermostats and change target temperature

## Usage example

ws = wavinsentio.WavinSentio("username","password")

## Release History

* 0.1.0
    * The first proper release